RSL: Nokia BTS reports TA in quarter-bits, not full bits.

We need to compensate accordingly...
diff --git a/openbsc/src/libbsc/abis_rsl.c b/openbsc/src/libbsc/abis_rsl.c
index d9084e1..029b62b 100644
--- a/openbsc/src/libbsc/abis_rsl.c
+++ b/openbsc/src/libbsc/abis_rsl.c
@@ -1008,8 +1008,9 @@
 		if (val[0] & 0x04)
 			mr->flags |= MEAS_REP_F_FPC;
 		mr->ms_l1.ta = val[1];
-		/* BS11 reports TA shifted by 2 bits */
-		if (msg->lchan->ts->trx->bts->type == GSM_BTS_TYPE_BS11)
+		/* BS11 and Nokia reports TA shifted by 2 bits */
+		if (msg->lchan->ts->trx->bts->type == GSM_BTS_TYPE_BS11
+		 || msg->lchan->ts->trx->bts->type == GSM_BTS_TYPE_NOKIA_SITE)
 			mr->ms_l1.ta >>= 2;
 	}
 	if (TLVP_PRESENT(&tp, RSL_IE_L3_INFO)) {